"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toBase64 = exports.toValAddress = exports.toAccAddress = exports.fromBase64 = exports.fromValAddress = exports.fromAccAddress = exports.registerGuardianValidator = exports.unpackHttpReponse = exports.getGuardianValidatorRegistrations = exports.getValidators = exports.getConsensusGuardianSet = exports.getGuardianSets = exports.executeGovernanceVAA = exports.getAddress = exports.getWallet = exports.getZeroFee = exports.getStargateClient = exports.getStargateQueryClient = exports.LCD_URL = exports.WORM_DENOM = exports.TENDERMINT_URL = void 0;
var fetch = require("node-fetch");
//@ts-ignore
globalThis.fetch = fetch;
const bech32_1 = require("bech32");
const proto_signing_1 = require("@cosmjs/proto-signing");
const stargate_1 = require("@cosmjs/stargate");
const tendermint_rpc_1 = require("@cosmjs/tendermint-rpc");
const wormhole_foundation_wormchain_wormhole_1 = require("../modules/wormhole_foundation.wormchain.wormhole");
const utils_1 = require("ethers/lib/utils");
let elliptic = require("elliptic"); //No TS defs?
//https://tutorials.cosmos.network/academy/4-my-own-chain/cosmjs.html
const ADDRESS_PREFIX = "wormhole";
const OPERATOR_PREFIX = "wormholevaloper";
exports.TENDERMINT_URL = "http://localhost:26658";
exports.WORM_DENOM = "uworm";
exports.LCD_URL = "http://localhost:1318";
async function getStargateQueryClient() {
    const tmClient = await tendermint_rpc_1.Tendermint34Client.connect(exports.TENDERMINT_URL);
    const client = stargate_1.QueryClient.withExtensions(tmClient, stargate_1.setupTxExtension, stargate_1.setupGovExtension, stargate_1.setupIbcExtension, stargate_1.setupAuthExtension, stargate_1.setupBankExtension, stargate_1.setupMintExtension, stargate_1.setupStakingExtension);
    return client;
}
exports.getStargateQueryClient = getStargateQueryClient;
async function getStargateClient() {
    const client = await stargate_1.StargateClient.connect(exports.TENDERMINT_URL);
    return client;
}
exports.getStargateClient = getStargateClient;
function getZeroFee() {
    return {
        amount: (0, proto_signing_1.coins)(0, exports.WORM_DENOM),
        gas: "180000", // 180k",
    };
}
exports.getZeroFee = getZeroFee;
async function getWallet(mnemonic) {
    const wallet = await proto_signing_1.DirectSecp256k1HdWallet.fromMnemonic(mnemonic, {
        prefix: ADDRESS_PREFIX,
    });
    return wallet;
}
exports.getWallet = getWallet;
async function getAddress(wallet) {
    //There are actually up to 5 accounts in a cosmos wallet. I believe this returns the first wallet.
    const [{ address }] = await wallet.getAccounts();
    return address;
}
exports.getAddress = getAddress;
async function executeGovernanceVAA(wallet, hexVaa) {
    const offline = wallet;
    const client = await (0, wormhole_foundation_wormchain_wormhole_1.txClient)(offline, { addr: exports.TENDERMINT_URL });
    const msg = client.msgExecuteGovernanceVAA({
        vaa: new Uint8Array(),
        signer: await getAddress(wallet),
    }); //TODO convert type
    const signingClient = await stargate_1.SigningStargateClient.connectWithSigner(exports.TENDERMINT_URL, wallet
    //{ gasPrice: { amount: Decimal.fromUserInput("0.0", 0), denom: "uworm" } }
    );
    //TODO investigate signing with the stargate client, as the module txClients can't do 100% of the operations
    const output = signingClient.signAndBroadcast(await getAddress(wallet), [msg], getZeroFee(), "executing governance VAA");
    //TODO the EncodingObjects from the txClient seem to be incompatible with the
    //stargate client
    // In order for all the encoding objects to be interoperable, we will have to either coerce the txClient msgs into the format of stargate,
    // or we could just just txClients for everything. I am currently leaning towards the latter, as we can generate txClients for everything out of the cosmos-sdk,
    // and we will likely need to generate txClients for our forked version of the cosmos SDK anyway.
    //const output = await client.signAndBroadcast([msg]);
    return output;
}
exports.executeGovernanceVAA = executeGovernanceVAA;
async function getGuardianSets() {
    const client = await (0, wormhole_foundation_wormchain_wormhole_1.queryClient)({ addr: exports.LCD_URL });
    const response = client.queryGuardianSetAll();
    return await unpackHttpReponse(response);
}
exports.getGuardianSets = getGuardianSets;
async function getConsensusGuardianSet() {
    const client = await (0, wormhole_foundation_wormchain_wormhole_1.queryClient)({ addr: exports.LCD_URL });
    const response = client.queryConsensusGuardianSetIndex();
    return await unpackHttpReponse(response);
}
exports.getConsensusGuardianSet = getConsensusGuardianSet;
async function getValidators() {
    const client = await getStargateQueryClient();
    //TODO handle pagination here
    const validators = await client.staking.validators("BOND_STATUS_BONDED");
    return validators;
}
exports.getValidators = getValidators;
async function getGuardianValidatorRegistrations() {
    const client = await (0, wormhole_foundation_wormchain_wormhole_1.queryClient)({ addr: exports.LCD_URL });
    const response = client.queryGuardianValidatorAll();
    return await unpackHttpReponse(response);
}
exports.getGuardianValidatorRegistrations = getGuardianValidatorRegistrations;
async function unpackHttpReponse(response) {
    const http = await response;
    //TODO check rpc status
    const content = http.data;
    return content;
}
exports.unpackHttpReponse = unpackHttpReponse;
async function registerGuardianValidator(wallet, guardianPubkeyBase64, guardianPrivkeyHex, valAddress) {
    const ec = new elliptic.ec("secp256k1");
    const key = ec.keyFromPrivate(guardianPrivkeyHex);
    const binaryData = fromValAddress(valAddress);
    const bytes = binaryData.bytes;
    const hash = (0, utils_1.keccak256)(bytes);
    const signature = key.sign(hash, { canonical: true });
    const args = {
        signer: await getAddress(wallet),
        // guardianPubkey: GuardianKey.fromJSON(guardianPubkeyBase64), //TODO fix this type, it's bad
        signature: signature,
    };
    const offline = wallet;
    const client = await (0, wormhole_foundation_wormchain_wormhole_1.txClient)(offline, { addr: exports.TENDERMINT_URL });
    const msg = client.msgRegisterAccountAsGuardian(args);
    const output = await client.signAndBroadcast([msg]);
    return output;
}
exports.registerGuardianValidator = registerGuardianValidator;
function fromAccAddress(address) {
    return { bytes: Buffer.from(bech32_1.bech32.fromWords(bech32_1.bech32.decode(address).words)) };
}
exports.fromAccAddress = fromAccAddress;
function fromValAddress(valAddress) {
    return {
        bytes: Buffer.from(bech32_1.bech32.fromWords(bech32_1.bech32.decode(valAddress).words)),
    };
}
exports.fromValAddress = fromValAddress;
function fromBase64(address) {
    return { bytes: Buffer.from(address, "base64") };
}
exports.fromBase64 = fromBase64;
function toAccAddress(address) {
    return bech32_1.bech32.encode(ADDRESS_PREFIX, bech32_1.bech32.toWords(address.bytes));
}
exports.toAccAddress = toAccAddress;
function toValAddress(address) {
    return bech32_1.bech32.encode(OPERATOR_PREFIX, bech32_1.bech32.toWords(address.bytes));
}
exports.toValAddress = toValAddress;
function toBase64(address) {
    return Buffer.from(address.bytes).toString("base64");
}
exports.toBase64 = toBase64;
