/**
 * Params defines the parameters for the tokenfactory module.
 */
export interface Osmosistokenfactoryv1Beta1Params {
    denom_creation_fee?: V1Beta1Coin[];
    /** @format uint64 */
    denom_creation_gas_consume?: string;
}
export interface ProtobufAny {
    "@type"?: string;
}
export interface RpcStatus {
    /** @format int32 */
    code?: number;
    message?: string;
    details?: ProtobufAny[];
}
/**
* Coin defines a token with a denomination and an amount.

NOTE: The amount field is an Int which implements the custom method
signatures required by gogoproto.
*/
export interface V1Beta1Coin {
    denom?: string;
    amount?: string;
}
/**
* DenomAuthorityMetadata specifies metadata for addresses that have specific
capabilities over a token factory denom. Right now there is only one Admin
permission, but is planned to be extended to the future.
*/
export interface V1Beta1DenomAuthorityMetadata {
    admin?: string;
}
/**
* DenomUnit represents a struct that describes a given
denomination unit of the basic token.
*/
export interface V1Beta1DenomUnit {
    /** denom represents the string name of the given denom unit (e.g uatom). */
    denom?: string;
    /**
     * exponent represents power of 10 exponent that one must
     * raise the base_denom to in order to equal the given DenomUnit's denom
     * 1 denom = 1^exponent base_denom
     * (e.g. with a base_denom of uatom, one can create a DenomUnit of 'atom' with
     * exponent = 6, thus: 1 atom = 10^6 uatom).
     * @format int64
     */
    exponent?: number;
    aliases?: string[];
}
/**
* Metadata represents a struct that describes
a basic token.
*/
export interface V1Beta1Metadata {
    description?: string;
    denom_units?: V1Beta1DenomUnit[];
    /** base represents the base denom (should be the DenomUnit with exponent = 0). */
    base?: string;
    /**
     * display indicates the suggested denom that should be
     * displayed in clients.
     */
    display?: string;
    /** Since: cosmos-sdk 0.43 */
    name?: string;
    /**
     * symbol is the token symbol usually shown on exchanges (eg: ATOM). This can
     * be the same as the display.
     *
     * Since: cosmos-sdk 0.43
     */
    symbol?: string;
}
export declare type V1Beta1MsgBurnResponse = object;
/**
* MsgChangeAdminResponse defines the response structure for an executed
MsgChangeAdmin message.
*/
export declare type V1Beta1MsgChangeAdminResponse = object;
export interface V1Beta1MsgCreateDenomResponse {
    new_token_denom?: string;
}
export declare type V1Beta1MsgForceTransferResponse = object;
export declare type V1Beta1MsgMintResponse = object;
/**
* MsgSetDenomMetadataResponse defines the response structure for an executed
MsgSetDenomMetadata message.
*/
export declare type V1Beta1MsgSetDenomMetadataResponse = object;
/**
* QueryDenomAuthorityMetadataResponse defines the response structure for the
DenomAuthorityMetadata gRPC query.
*/
export interface V1Beta1QueryDenomAuthorityMetadataResponse {
    /**
     * DenomAuthorityMetadata specifies metadata for addresses that have specific
     * capabilities over a token factory denom. Right now there is only one Admin
     * permission, but is planned to be extended to the future.
     */
    authority_metadata?: V1Beta1DenomAuthorityMetadata;
}
/**
* QueryDenomsFromCreatorRequest defines the response structure for the
DenomsFromCreator gRPC query.
*/
export interface V1Beta1QueryDenomsFromCreatorResponse {
    denoms?: string[];
}
/**
 * QueryParamsResponse is the response type for the Query/Params RPC method.
 */
export interface V1Beta1QueryParamsResponse {
    /** params defines the parameters of the module. */
    params?: Osmosistokenfactoryv1Beta1Params;
}
export declare type QueryParamsType = Record<string | number, any>;
export declare type ResponseFormat = keyof Omit<Body, "body" | "bodyUsed">;
export interface FullRequestParams extends Omit<RequestInit, "body"> {
    /** set parameter to `true` for call `securityWorker` for this request */
    secure?: boolean;
    /** request path */
    path: string;
    /** content type of request body */
    type?: ContentType;
    /** query params */
    query?: QueryParamsType;
    /** format of response (i.e. response.json() -> format: "json") */
    format?: keyof Omit<Body, "body" | "bodyUsed">;
    /** request body */
    body?: unknown;
    /** base url */
    baseUrl?: string;
    /** request cancellation token */
    cancelToken?: CancelToken;
}
export declare type RequestParams = Omit<FullRequestParams, "body" | "method" | "query" | "path">;
export interface ApiConfig<SecurityDataType = unknown> {
    baseUrl?: string;
    baseApiParams?: Omit<RequestParams, "baseUrl" | "cancelToken" | "signal">;
    securityWorker?: (securityData: SecurityDataType) => RequestParams | void;
}
export interface HttpResponse<D extends unknown, E extends unknown = unknown> extends Response {
    data: D;
    error: E;
}
declare type CancelToken = Symbol | string | number;
export declare enum ContentType {
    Json = "application/json",
    FormData = "multipart/form-data",
    UrlEncoded = "application/x-www-form-urlencoded"
}
export declare class HttpClient<SecurityDataType = unknown> {
    baseUrl: string;
    private securityData;
    private securityWorker;
    private abortControllers;
    private baseApiParams;
    constructor(apiConfig?: ApiConfig<SecurityDataType>);
    setSecurityData: (data: SecurityDataType) => void;
    private addQueryParam;
    protected toQueryString(rawQuery?: QueryParamsType): string;
    protected addQueryParams(rawQuery?: QueryParamsType): string;
    private contentFormatters;
    private mergeRequestParams;
    private createAbortSignal;
    abortRequest: (cancelToken: CancelToken) => void;
    request: <T = any, E = any>({ body, secure, path, type, query, format, baseUrl, cancelToken, ...params }: FullRequestParams) => Promise<HttpResponse<T, E>>;
}
/**
 * @title osmosis/tokenfactory/v1beta1/authorityMetadata.proto
 * @version version not set
 */
export declare class Api<SecurityDataType extends unknown> extends HttpClient<SecurityDataType> {
    /**
   * No description
   *
   * @tags Query
   * @name QueryDenomAuthorityMetadata
   * @summary DenomAuthorityMetadata defines a gRPC query method for fetching
  DenomAuthorityMetadata for a particular denom.
   * @request GET:/osmosis/tokenfactory/v1beta1/denoms/{denom}/authority_metadata
   */
    queryDenomAuthorityMetadata: (denom: string, params?: RequestParams) => Promise<HttpResponse<V1Beta1QueryDenomAuthorityMetadataResponse, RpcStatus>>;
    /**
   * No description
   *
   * @tags Query
   * @name QueryDenomsFromCreator
   * @summary DenomsFromCreator defines a gRPC query method for fetching all
  denominations created by a specific admin/creator.
   * @request GET:/osmosis/tokenfactory/v1beta1/denoms_from_creator/{creator}
   */
    queryDenomsFromCreator: (creator: string, params?: RequestParams) => Promise<HttpResponse<V1Beta1QueryDenomsFromCreatorResponse, RpcStatus>>;
    /**
   * No description
   *
   * @tags Query
   * @name QueryParams
   * @summary Params defines a gRPC query method that returns the tokenfactory module's
  parameters.
   * @request GET:/osmosis/tokenfactory/v1beta1/params
   */
    queryParams: (params?: RequestParams) => Promise<HttpResponse<V1Beta1QueryParamsResponse, RpcStatus>>;
}
export {};
