export interface ProtobufAny {
    "@type"?: string;
}
export interface RpcStatus {
    /** @format int32 */
    code?: number;
    message?: string;
    details?: ProtobufAny[];
}
/**
* message SomeRequest {
         Foo some_parameter = 1;
         PageRequest pagination = 2;
 }
*/
export interface V1Beta1PageRequest {
    /**
     * key is a value returned in PageResponse.next_key to begin
     * querying the next page most efficiently. Only one of offset or key
     * should be set.
     * @format byte
     */
    key?: string;
    /**
     * offset is a numeric offset that can be used when key is unavailable.
     * It is less efficient than using key. Only one of offset or key should
     * be set.
     * @format uint64
     */
    offset?: string;
    /**
     * limit is the total number of results to be returned in the result page.
     * If left empty it will default to a value to be set by each app.
     * @format uint64
     */
    limit?: string;
    /**
     * count_total is set to true  to indicate that the result set should include
     * a count of the total number of items available for pagination in UIs.
     * count_total is only respected when offset is used. It is ignored when key
     * is set.
     */
    count_total?: boolean;
    /**
     * reverse is set to true if results are to be returned in the descending order.
     *
     * Since: cosmos-sdk 0.43
     */
    reverse?: boolean;
}
/**
* PageResponse is to be embedded in gRPC response messages where the
corresponding request message has used PageRequest.

 message SomeResponse {
         repeated Bar results = 1;
         PageResponse page = 2;
 }
*/
export interface V1Beta1PageResponse {
    /** @format byte */
    next_key?: string;
    /** @format uint64 */
    total?: string;
}
export interface WormholeConfig {
    /** @format uint64 */
    guardian_set_expiration?: string;
    /** @format byte */
    governance_emitter?: string;
    /** @format int64 */
    governance_chain?: number;
    /** @format int64 */
    chain_id?: number;
}
export interface WormholeConsensusGuardianSetIndex {
    /** @format int64 */
    index?: number;
}
export declare type WormholeEmptyResponse = object;
export interface WormholeGuardianSet {
    /** @format int64 */
    index?: number;
    keys?: string[];
    /** @format uint64 */
    expirationTime?: string;
}
export interface WormholeGuardianValidator {
    /** @format byte */
    guardianKey?: string;
    /** @format byte */
    validatorAddr?: string;
}
export declare type WormholeMsgAllowlistResponse = object;
export declare type WormholeMsgExecuteGovernanceVAAResponse = object;
export interface WormholeMsgInstantiateContractResponse {
    /** Address is the bech32 address of the new contract instance. */
    address?: string;
    /** @format byte */
    data?: string;
}
/**
 * MsgMigrateContractResponse returns contract migration result data.
 */
export interface WormholeMsgMigrateContractResponse {
    /** @format byte */
    data?: string;
}
export declare type WormholeMsgRegisterAccountAsGuardianResponse = object;
export interface WormholeMsgStoreCodeResponse {
    /** @format uint64 */
    code_id?: string;
    /** @format byte */
    checksum?: string;
}
export declare type WormholeMsgWasmInstantiateAllowlistResponse = object;
export interface WormholeQueryAllGuardianSetResponse {
    GuardianSet?: WormholeGuardianSet[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeQueryAllGuardianValidatorResponse {
    guardianValidator?: WormholeGuardianValidator[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeQueryAllReplayProtectionResponse {
    replayProtection?: WormholeReplayProtection[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeQueryAllSequenceCounterResponse {
    sequenceCounter?: WormholeSequenceCounter[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeQueryAllValidatorAllowlistResponse {
    allowlist?: WormholeValidatorAllowedAddress[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeQueryAllWasmInstantiateAllowlistResponse {
    allowlist?: WormholeWasmInstantiateAllowedContractCodeId[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeQueryGetConfigResponse {
    Config?: WormholeConfig;
}
export interface WormholeQueryGetConsensusGuardianSetIndexResponse {
    ConsensusGuardianSetIndex?: WormholeConsensusGuardianSetIndex;
}
export interface WormholeQueryGetGuardianSetResponse {
    GuardianSet?: WormholeGuardianSet;
}
export interface WormholeQueryGetGuardianValidatorResponse {
    guardianValidator?: WormholeGuardianValidator;
}
export interface WormholeQueryGetReplayProtectionResponse {
    replayProtection?: WormholeReplayProtection;
}
export interface WormholeQueryGetSequenceCounterResponse {
    sequenceCounter?: WormholeSequenceCounter;
}
export interface WormholeQueryIbcComposabilityMwContractResponse {
    contractAddress?: string;
}
export interface WormholeQueryLatestGuardianSetIndexResponse {
    /** @format int64 */
    latestGuardianSetIndex?: number;
}
export interface WormholeQueryValidatorAllowlistResponse {
    validator_address?: string;
    allowlist?: WormholeValidatorAllowedAddress[];
    /**
     * PageResponse is to be embedded in gRPC response messages where the
     * corresponding request message has used PageRequest.
     *
     *  message SomeResponse {
     *          repeated Bar results = 1;
     *          PageResponse page = 2;
     *  }
     */
    pagination?: V1Beta1PageResponse;
}
export interface WormholeReplayProtection {
    index?: string;
}
export interface WormholeSequenceCounter {
    index?: string;
    /** @format uint64 */
    sequence?: string;
}
export interface WormholeValidatorAllowedAddress {
    validator_address?: string;
    allowed_address?: string;
    name?: string;
}
export interface WormholeWasmInstantiateAllowedContractCodeId {
    contract_address?: string;
    /** @format uint64 */
    code_id?: string;
}
export declare type QueryParamsType = Record<string | number, any>;
export declare type ResponseFormat = keyof Omit<Body, "body" | "bodyUsed">;
export interface FullRequestParams extends Omit<RequestInit, "body"> {
    /** set parameter to `true` for call `securityWorker` for this request */
    secure?: boolean;
    /** request path */
    path: string;
    /** content type of request body */
    type?: ContentType;
    /** query params */
    query?: QueryParamsType;
    /** format of response (i.e. response.json() -> format: "json") */
    format?: keyof Omit<Body, "body" | "bodyUsed">;
    /** request body */
    body?: unknown;
    /** base url */
    baseUrl?: string;
    /** request cancellation token */
    cancelToken?: CancelToken;
}
export declare type RequestParams = Omit<FullRequestParams, "body" | "method" | "query" | "path">;
export interface ApiConfig<SecurityDataType = unknown> {
    baseUrl?: string;
    baseApiParams?: Omit<RequestParams, "baseUrl" | "cancelToken" | "signal">;
    securityWorker?: (securityData: SecurityDataType) => RequestParams | void;
}
export interface HttpResponse<D extends unknown, E extends unknown = unknown> extends Response {
    data: D;
    error: E;
}
declare type CancelToken = Symbol | string | number;
export declare enum ContentType {
    Json = "application/json",
    FormData = "multipart/form-data",
    UrlEncoded = "application/x-www-form-urlencoded"
}
export declare class HttpClient<SecurityDataType = unknown> {
    baseUrl: string;
    private securityData;
    private securityWorker;
    private abortControllers;
    private baseApiParams;
    constructor(apiConfig?: ApiConfig<SecurityDataType>);
    setSecurityData: (data: SecurityDataType) => void;
    private addQueryParam;
    protected toQueryString(rawQuery?: QueryParamsType): string;
    protected addQueryParams(rawQuery?: QueryParamsType): string;
    private contentFormatters;
    private mergeRequestParams;
    private createAbortSignal;
    abortRequest: (cancelToken: CancelToken) => void;
    request: <T = any, E = any>({ body, secure, path, type, query, format, baseUrl, cancelToken, ...params }: FullRequestParams) => Promise<HttpResponse<T, E>>;
}
/**
 * @title wormhole/config.proto
 * @version version not set
 */
export declare class Api<SecurityDataType extends unknown> extends HttpClient<SecurityDataType> {
    /**
     * No description
     *
     * @tags Query
     * @name QueryAllowlistAll
     * @request GET:/wormhole_foundation/wormchain/wormhole/allowlist
     */
    queryAllowlistAll: (query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryAllValidatorAllowlistResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryAllowlist
     * @request GET:/wormhole_foundation/wormchain/wormhole/allowlist/{validator_address}
     */
    queryAllowlist: (validator_address: string, query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryValidatorAllowlistResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryConfig
     * @summary Queries a config by index.
     * @request GET:/wormhole_foundation/wormchain/wormhole/config
     */
    queryConfig: (params?: RequestParams) => Promise<HttpResponse<WormholeQueryGetConfigResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryConsensusGuardianSetIndex
     * @summary Queries a ConsensusGuardianSetIndex by index.
     * @request GET:/wormhole_foundation/wormchain/wormhole/consensus_guardian_set_index
     */
    queryConsensusGuardianSetIndex: (params?: RequestParams) => Promise<HttpResponse<WormholeQueryGetConsensusGuardianSetIndexResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryGuardianSetAll
     * @summary Queries a list of guardianSet items.
     * @request GET:/wormhole_foundation/wormchain/wormhole/guardianSet
     */
    queryGuardianSetAll: (query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryAllGuardianSetResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryGuardianSet
     * @summary Queries a guardianSet by index.
     * @request GET:/wormhole_foundation/wormchain/wormhole/guardianSet/{index}
     */
    queryGuardianSet: (index: number, params?: RequestParams) => Promise<HttpResponse<WormholeQueryGetGuardianSetResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryGuardianValidatorAll
     * @summary Queries a list of GuardianValidator items.
     * @request GET:/wormhole_foundation/wormchain/wormhole/guardian_validator
     */
    queryGuardianValidatorAll: (query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryAllGuardianValidatorResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryGuardianValidator
     * @summary Queries a GuardianValidator by index.
     * @request GET:/wormhole_foundation/wormchain/wormhole/guardian_validator/{guardianKey}
     */
    queryGuardianValidator: (guardianKey: string, params?: RequestParams) => Promise<HttpResponse<WormholeQueryGetGuardianValidatorResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryIbcComposabilityMwContract
     * @request GET:/wormhole_foundation/wormchain/wormhole/ibc_composability_mw_contract
     */
    queryIbcComposabilityMwContract: (params?: RequestParams) => Promise<HttpResponse<WormholeQueryIbcComposabilityMwContractResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryLatestGuardianSetIndex
     * @summary Queries a list of LatestGuardianSetIndex items.
     * @request GET:/wormhole_foundation/wormchain/wormhole/latest_guardian_set_index
     */
    queryLatestGuardianSetIndex: (params?: RequestParams) => Promise<HttpResponse<WormholeQueryLatestGuardianSetIndexResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryReplayProtectionAll
     * @summary Queries a list of replayProtection items.
     * @request GET:/wormhole_foundation/wormchain/wormhole/replayProtection
     */
    queryReplayProtectionAll: (query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryAllReplayProtectionResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryReplayProtection
     * @summary Queries a replayProtection by index.
     * @request GET:/wormhole_foundation/wormchain/wormhole/replayProtection/{index}
     */
    queryReplayProtection: (index: string, params?: RequestParams) => Promise<HttpResponse<WormholeQueryGetReplayProtectionResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QuerySequenceCounterAll
     * @summary Queries a list of sequenceCounter items.
     * @request GET:/wormhole_foundation/wormchain/wormhole/sequenceCounter
     */
    querySequenceCounterAll: (query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryAllSequenceCounterResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QuerySequenceCounter
     * @summary Queries a sequenceCounter by index.
     * @request GET:/wormhole_foundation/wormchain/wormhole/sequenceCounter/{index}
     */
    querySequenceCounter: (index: string, params?: RequestParams) => Promise<HttpResponse<WormholeQueryGetSequenceCounterResponse, RpcStatus>>;
    /**
     * No description
     *
     * @tags Query
     * @name QueryWasmInstantiateAllowlistAll
     * @request GET:/wormhole_foundation/wormchain/wormhole/wasm_instantiate_allowlist
     */
    queryWasmInstantiateAllowlistAll: (query?: {
        "pagination.key"?: string | undefined;
        "pagination.offset"?: string | undefined;
        "pagination.limit"?: string | undefined;
        "pagination.count_total"?: boolean | undefined;
        "pagination.reverse"?: boolean | undefined;
    } | undefined, params?: RequestParams) => Promise<HttpResponse<WormholeQueryAllWasmInstantiateAllowlistResponse, RpcStatus>>;
}
export {};
