import { Reader, Writer } from "protobufjs/minimal";
export declare const protobufPackage = "wormhole_foundation.wormchain.wormhole";
export interface EmptyResponse {
}
export interface MsgCreateAllowlistEntryRequest {
    /** signer should be a guardian validator in a current set or future set. */
    signer: string;
    /** the address to allowlist */
    address: string;
    /** optional human readable name for the entry */
    name: string;
}
export interface MsgDeleteAllowlistEntryRequest {
    /** signer should be a guardian validator in a current set or future set. */
    signer: string;
    /** the address allowlist to remove */
    address: string;
}
export interface MsgAllowlistResponse {
}
export interface MsgExecuteGovernanceVAA {
    vaa: Uint8Array;
    signer: string;
}
export interface MsgExecuteGovernanceVAAResponse {
}
export interface MsgRegisterAccountAsGuardian {
    signer: string;
    signature: Uint8Array;
}
export interface MsgRegisterAccountAsGuardianResponse {
}
/** Same as from x/wasmd but with vaa auth */
export interface MsgStoreCode {
    /** Signer is the that actor that signed the messages */
    signer: string;
    /** WASMByteCode can be raw or gzip compressed */
    wasm_byte_code: Uint8Array;
    /** vaa must be governance msg with payload containing sha3 256 hash of `wasm_byte_code` */
    vaa: Uint8Array;
}
export interface MsgStoreCodeResponse {
    /** CodeID is the reference to the stored WASM code */
    code_id: number;
    /** Checksum is the sha256 hash of the stored code */
    checksum: Uint8Array;
}
/** Same as from x/wasmd but with vaa auth */
export interface MsgInstantiateContract {
    /** Signer is the that actor that signed the messages */
    signer: string;
    /** CodeID is the reference to the stored WASM code */
    code_id: number;
    /** Label is optional metadata to be stored with a contract instance. */
    label: string;
    /** Msg json encoded message to be passed to the contract on instantiation */
    msg: Uint8Array;
    /** vaa must be governance msg with payload containing keccak256 hash(hash(hash(BigEndian(CodeID)), Label), Msg) */
    vaa: Uint8Array;
}
export interface MsgInstantiateContractResponse {
    /** Address is the bech32 address of the new contract instance. */
    address: string;
    /** Data contains base64-encoded bytes to returned from the contract */
    data: Uint8Array;
}
export interface MsgAddWasmInstantiateAllowlist {
    /** Signer is the actor that signed the messages */
    signer: string;
    /** Address is the bech32 address of the contract that can call wasm instantiate without a VAA */
    address: string;
    /** CodeID is the reference to the stored WASM code that can be instantiated */
    code_id: number;
    /** vaa is the WormchainAddWasmInstantiateAllowlist governance message */
    vaa: Uint8Array;
}
export interface MsgDeleteWasmInstantiateAllowlist {
    /** signer should be a guardian validator in a current set or future set. */
    signer: string;
    /** the <contract, code_id> pair to remove */
    address: string;
    code_id: number;
    /** vaa is the WormchainDeleteWasmInstantiateAllowlist governance message */
    vaa: Uint8Array;
}
export interface MsgWasmInstantiateAllowlistResponse {
}
/** MsgMigrateContract runs a code upgrade/ downgrade for a smart contract */
export interface MsgMigrateContract {
    /** Sender is the actor that signs the messages */
    signer: string;
    /** Contract is the address of the smart contract */
    contract: string;
    /** CodeID references the new WASM code */
    code_id: number;
    /** Msg json encoded message to be passed to the contract on migration */
    msg: Uint8Array;
    /** vaa must be governance msg with payload containing keccak256 hash(hash(hash(BigEndian(CodeID)), Contract), Msg) */
    vaa: Uint8Array;
}
/** MsgMigrateContractResponse returns contract migration result data. */
export interface MsgMigrateContractResponse {
    /**
     * Data contains same raw bytes returned as data from the wasm contract.
     * (May be empty)
     */
    data: Uint8Array;
}
export interface MsgExecuteGatewayGovernanceVaa {
    /** Sender is the actor that signs the messages */
    signer: string;
    /** vaa must be governance msg with valid module, action, and payload */
    vaa: Uint8Array;
}
export declare const EmptyResponse: {
    encode(_: EmptyResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): EmptyResponse;
    fromJSON(_: any): EmptyResponse;
    toJSON(_: EmptyResponse): unknown;
    fromPartial(_: DeepPartial<EmptyResponse>): EmptyResponse;
};
export declare const MsgCreateAllowlistEntryRequest: {
    encode(message: MsgCreateAllowlistEntryRequest, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgCreateAllowlistEntryRequest;
    fromJSON(object: any): MsgCreateAllowlistEntryRequest;
    toJSON(message: MsgCreateAllowlistEntryRequest): unknown;
    fromPartial(object: DeepPartial<MsgCreateAllowlistEntryRequest>): MsgCreateAllowlistEntryRequest;
};
export declare const MsgDeleteAllowlistEntryRequest: {
    encode(message: MsgDeleteAllowlistEntryRequest, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgDeleteAllowlistEntryRequest;
    fromJSON(object: any): MsgDeleteAllowlistEntryRequest;
    toJSON(message: MsgDeleteAllowlistEntryRequest): unknown;
    fromPartial(object: DeepPartial<MsgDeleteAllowlistEntryRequest>): MsgDeleteAllowlistEntryRequest;
};
export declare const MsgAllowlistResponse: {
    encode(_: MsgAllowlistResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgAllowlistResponse;
    fromJSON(_: any): MsgAllowlistResponse;
    toJSON(_: MsgAllowlistResponse): unknown;
    fromPartial(_: DeepPartial<MsgAllowlistResponse>): MsgAllowlistResponse;
};
export declare const MsgExecuteGovernanceVAA: {
    encode(message: MsgExecuteGovernanceVAA, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgExecuteGovernanceVAA;
    fromJSON(object: any): MsgExecuteGovernanceVAA;
    toJSON(message: MsgExecuteGovernanceVAA): unknown;
    fromPartial(object: DeepPartial<MsgExecuteGovernanceVAA>): MsgExecuteGovernanceVAA;
};
export declare const MsgExecuteGovernanceVAAResponse: {
    encode(_: MsgExecuteGovernanceVAAResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgExecuteGovernanceVAAResponse;
    fromJSON(_: any): MsgExecuteGovernanceVAAResponse;
    toJSON(_: MsgExecuteGovernanceVAAResponse): unknown;
    fromPartial(_: DeepPartial<MsgExecuteGovernanceVAAResponse>): MsgExecuteGovernanceVAAResponse;
};
export declare const MsgRegisterAccountAsGuardian: {
    encode(message: MsgRegisterAccountAsGuardian, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgRegisterAccountAsGuardian;
    fromJSON(object: any): MsgRegisterAccountAsGuardian;
    toJSON(message: MsgRegisterAccountAsGuardian): unknown;
    fromPartial(object: DeepPartial<MsgRegisterAccountAsGuardian>): MsgRegisterAccountAsGuardian;
};
export declare const MsgRegisterAccountAsGuardianResponse: {
    encode(_: MsgRegisterAccountAsGuardianResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgRegisterAccountAsGuardianResponse;
    fromJSON(_: any): MsgRegisterAccountAsGuardianResponse;
    toJSON(_: MsgRegisterAccountAsGuardianResponse): unknown;
    fromPartial(_: DeepPartial<MsgRegisterAccountAsGuardianResponse>): MsgRegisterAccountAsGuardianResponse;
};
export declare const MsgStoreCode: {
    encode(message: MsgStoreCode, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgStoreCode;
    fromJSON(object: any): MsgStoreCode;
    toJSON(message: MsgStoreCode): unknown;
    fromPartial(object: DeepPartial<MsgStoreCode>): MsgStoreCode;
};
export declare const MsgStoreCodeResponse: {
    encode(message: MsgStoreCodeResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgStoreCodeResponse;
    fromJSON(object: any): MsgStoreCodeResponse;
    toJSON(message: MsgStoreCodeResponse): unknown;
    fromPartial(object: DeepPartial<MsgStoreCodeResponse>): MsgStoreCodeResponse;
};
export declare const MsgInstantiateContract: {
    encode(message: MsgInstantiateContract, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgInstantiateContract;
    fromJSON(object: any): MsgInstantiateContract;
    toJSON(message: MsgInstantiateContract): unknown;
    fromPartial(object: DeepPartial<MsgInstantiateContract>): MsgInstantiateContract;
};
export declare const MsgInstantiateContractResponse: {
    encode(message: MsgInstantiateContractResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgInstantiateContractResponse;
    fromJSON(object: any): MsgInstantiateContractResponse;
    toJSON(message: MsgInstantiateContractResponse): unknown;
    fromPartial(object: DeepPartial<MsgInstantiateContractResponse>): MsgInstantiateContractResponse;
};
export declare const MsgAddWasmInstantiateAllowlist: {
    encode(message: MsgAddWasmInstantiateAllowlist, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgAddWasmInstantiateAllowlist;
    fromJSON(object: any): MsgAddWasmInstantiateAllowlist;
    toJSON(message: MsgAddWasmInstantiateAllowlist): unknown;
    fromPartial(object: DeepPartial<MsgAddWasmInstantiateAllowlist>): MsgAddWasmInstantiateAllowlist;
};
export declare const MsgDeleteWasmInstantiateAllowlist: {
    encode(message: MsgDeleteWasmInstantiateAllowlist, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgDeleteWasmInstantiateAllowlist;
    fromJSON(object: any): MsgDeleteWasmInstantiateAllowlist;
    toJSON(message: MsgDeleteWasmInstantiateAllowlist): unknown;
    fromPartial(object: DeepPartial<MsgDeleteWasmInstantiateAllowlist>): MsgDeleteWasmInstantiateAllowlist;
};
export declare const MsgWasmInstantiateAllowlistResponse: {
    encode(_: MsgWasmInstantiateAllowlistResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgWasmInstantiateAllowlistResponse;
    fromJSON(_: any): MsgWasmInstantiateAllowlistResponse;
    toJSON(_: MsgWasmInstantiateAllowlistResponse): unknown;
    fromPartial(_: DeepPartial<MsgWasmInstantiateAllowlistResponse>): MsgWasmInstantiateAllowlistResponse;
};
export declare const MsgMigrateContract: {
    encode(message: MsgMigrateContract, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgMigrateContract;
    fromJSON(object: any): MsgMigrateContract;
    toJSON(message: MsgMigrateContract): unknown;
    fromPartial(object: DeepPartial<MsgMigrateContract>): MsgMigrateContract;
};
export declare const MsgMigrateContractResponse: {
    encode(message: MsgMigrateContractResponse, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgMigrateContractResponse;
    fromJSON(object: any): MsgMigrateContractResponse;
    toJSON(message: MsgMigrateContractResponse): unknown;
    fromPartial(object: DeepPartial<MsgMigrateContractResponse>): MsgMigrateContractResponse;
};
export declare const MsgExecuteGatewayGovernanceVaa: {
    encode(message: MsgExecuteGatewayGovernanceVaa, writer?: Writer): Writer;
    decode(input: Reader | Uint8Array, length?: number | undefined): MsgExecuteGatewayGovernanceVaa;
    fromJSON(object: any): MsgExecuteGatewayGovernanceVaa;
    toJSON(message: MsgExecuteGatewayGovernanceVaa): unknown;
    fromPartial(object: DeepPartial<MsgExecuteGatewayGovernanceVaa>): MsgExecuteGatewayGovernanceVaa;
};
/** Msg defines the Msg service. */
export interface Msg {
    ExecuteGovernanceVAA(request: MsgExecuteGovernanceVAA): Promise<MsgExecuteGovernanceVAAResponse>;
    RegisterAccountAsGuardian(request: MsgRegisterAccountAsGuardian): Promise<MsgRegisterAccountAsGuardianResponse>;
    CreateAllowlistEntry(request: MsgCreateAllowlistEntryRequest): Promise<MsgAllowlistResponse>;
    DeleteAllowlistEntry(request: MsgDeleteAllowlistEntryRequest): Promise<MsgAllowlistResponse>;
    /** StoreCode to submit Wasm code to the system */
    StoreCode(request: MsgStoreCode): Promise<MsgStoreCodeResponse>;
    /** Instantiate creates a new smart contract instance for the given code id. */
    InstantiateContract(request: MsgInstantiateContract): Promise<MsgInstantiateContractResponse>;
    AddWasmInstantiateAllowlist(request: MsgAddWasmInstantiateAllowlist): Promise<MsgWasmInstantiateAllowlistResponse>;
    DeleteWasmInstantiateAllowlist(request: MsgDeleteWasmInstantiateAllowlist): Promise<MsgWasmInstantiateAllowlistResponse>;
    MigrateContract(request: MsgMigrateContract): Promise<MsgMigrateContractResponse>;
    /** this line is used by starport scaffolding # proto/tx/rpc */
    ExecuteGatewayGovernanceVaa(request: MsgExecuteGatewayGovernanceVaa): Promise<EmptyResponse>;
}
export declare class MsgClientImpl implements Msg {
    private readonly rpc;
    constructor(rpc: Rpc);
    ExecuteGovernanceVAA(request: MsgExecuteGovernanceVAA): Promise<MsgExecuteGovernanceVAAResponse>;
    RegisterAccountAsGuardian(request: MsgRegisterAccountAsGuardian): Promise<MsgRegisterAccountAsGuardianResponse>;
    CreateAllowlistEntry(request: MsgCreateAllowlistEntryRequest): Promise<MsgAllowlistResponse>;
    DeleteAllowlistEntry(request: MsgDeleteAllowlistEntryRequest): Promise<MsgAllowlistResponse>;
    StoreCode(request: MsgStoreCode): Promise<MsgStoreCodeResponse>;
    InstantiateContract(request: MsgInstantiateContract): Promise<MsgInstantiateContractResponse>;
    AddWasmInstantiateAllowlist(request: MsgAddWasmInstantiateAllowlist): Promise<MsgWasmInstantiateAllowlistResponse>;
    DeleteWasmInstantiateAllowlist(request: MsgDeleteWasmInstantiateAllowlist): Promise<MsgWasmInstantiateAllowlistResponse>;
    MigrateContract(request: MsgMigrateContract): Promise<MsgMigrateContractResponse>;
    ExecuteGatewayGovernanceVaa(request: MsgExecuteGatewayGovernanceVaa): Promise<EmptyResponse>;
}
interface Rpc {
    request(service: string, method: string, data: Uint8Array): Promise<Uint8Array>;
}
declare type Builtin = Date | Function | Uint8Array | string | number | undefined;
export declare type DeepPartial<T> = T extends Builtin ? T : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
